diff --git a/modules/gui/qt4/components/interface_widgets.cpp b/modules/gui/qt4/components/interface_widgets.cpp
index 207699e..f105095 100644
--- a/modules/gui/qt4/components/interface_widgets.cpp
+++ b/modules/gui/qt4/components/interface_widgets.cpp
@@ -934,6 +934,13 @@ FullscreenControllerWidget::FullscreenControllerWidget( intf_thread_t *_p_i,
     fscHidden = true;
     show();
     #endif
+
+    /* it is fine to know, when new-vout is created, because it means
+       old callbacks were dropped and we need to register them again
+       So we create variable for it with pointer to new vout,
+       in vout_intf.c in vout_IntfInit() */
+    var_Create( p_intf->p_libvlc, "new-vout", VLC_VAR_ADDRESS );
+    var_AddCallback( p_intf->p_libvlc, "new-vout", newVoutCallback, this );
 }
 
 FullscreenControllerWidget::~FullscreenControllerWidget()
@@ -1141,6 +1148,19 @@ void FullscreenControllerWidget::unregFullscreenCallback()
 }
 
 /**
+ * Call when new vout is created
+ */
+static int newVoutCallback( vlc_object_t *vlc_object, const char *variable,
+                            vlc_value_t old_val, vlc_value_t new_val,
+                            void *data )
+{
+    FullscreenControllerWidget *p_fs = ( FullscreenControllerWidget * ) data;
+    p_fs->regFullscreenCallback( ( vout_thread_t * ) new_val.p_object );
+
+    return VLC_SUCCESS;
+}
+
+/**
  * Register and unregister callback for mouse moving
  */
 static int regMouseMoveCallback( vlc_object_t *vlc_object, const char *variable,
diff --git a/modules/gui/qt4/components/interface_widgets.hpp b/modules/gui/qt4/components/interface_widgets.hpp
index 762ae5c..4f59e9b 100644
--- a/modules/gui/qt4/components/interface_widgets.hpp
+++ b/modules/gui/qt4/components/interface_widgets.hpp
@@ -236,6 +236,9 @@ signals:
  * Fullscreen controller
  ***********************************/
 
+static int newVoutCallback( vlc_object_t *vlc_object, const char *variable, vlc_value_t old_val,
+    vlc_value_t new_val, void *data );
+
 static int showFullscreenControllCallback(vlc_object_t *vlc_object, const char *variable, vlc_value_t old_val,
     vlc_value_t new_val, void *data);
 
diff --git a/src/video_output/vout_intf.c b/src/video_output/vout_intf.c
index 78a3c63..baa91f7 100644
--- a/src/video_output/vout_intf.c
+++ b/src/video_output/vout_intf.c
@@ -429,6 +429,10 @@ void vout_IntfInit( vout_thread_t *p_vout )
 
     var_Create( p_vout, "intf-change", VLC_VAR_BOOL );
     var_SetBool( p_vout, "intf-change", true );
+
+    vlc_value_t value;
+    value.p_object = ( vlc_object_t * ) p_vout;
+    var_Set( p_vout->p_libvlc, "new-vout", value );
 }
 
 /*****************************************************************************
